@@ -29,11 +29,12 @@ mainwindow::mainwindow(QWidget *parent) :
     }
 
     ui->buttonBox->button(QDialogButtonBox::Help)->setText(tr("About"));
+    ui->buttonBox->button(QDialogButtonBox::Save)->setText(tr("Save"));
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
     orientationChanged();
     readvalues();
     abouttext = tr("Author: d-iivil<br />Licence: GPL");
-    abouttitle = "CSSU Transitions Tuner " + tr("version") + " 0.1.0";
+    abouttitle = "CSSU Transitions Tuner " + tr("version") + " 0.1.1";
 }
 
 mainwindow::~mainwindow()
@@ -213,7 +214,13 @@ void mainwindow::storevalues()
     QSettings settings3(path3, QSettings::IniFormat);
 
     double parallaxint = ui->parallax->value();
-    if (parallaxint == 0) parallaxint = 1;
+    double ylaraja = 1;
+    double alaraja = -1;
+    if (parallaxint <= ylaraja && parallaxint >= 0) {
+        parallaxint = 1;
+    } else if (parallaxint >= alaraja && parallaxint <= 0) {
+        parallaxint = -1;
+    }
     QString parallax = QString::number(parallaxint);
     parallax.replace(',', '.');
 
@@ -431,6 +438,7 @@ void mainwindow::on_buttonBox_clicked(QAbstractButton* button)
             msgBox.setWindowTitle(tr("Transitions updated!"));
             msgBox.setText(tr("Reboot is required to activate all changes."));
 	    msgBox.exec();
+            readvalues();
 	    break;
 	}
 	default:;
